A simple greeting package

To login: UserID: paramaveer.yaduvanshi
Go to: https://pypi.org/account/login/

To gerenate token
Go to: https://pypi.org/manage/account/#api-tokens

Commads to be run:
----------To prepare env
pip install --upgrade build twine
----------To generate files /dist/*
python -m build
----------To upload /dist/*
python -m twine upload dist/*
